@@ -11,12 +11,61 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.cdk
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.33.0", __name__, "aws-kms@0.33.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.34.0", __name__, "aws-kms@0.34.0.jsii.tgz")
+@jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasAttributes", jsii_struct_bases=[])
+class AliasAttributes(jsii.compat.TypedDict):
+    """
+    Stability:
+        experimental
+    """
+    aliasName: str
+    """
+    Stability:
+        experimental
+    """
+
+    aliasTargetKey: "IKey"
+    """
+    Stability:
+        experimental
+    """
+
+@jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasProps", jsii_struct_bases=[])
+class AliasProps(jsii.compat.TypedDict):
+    """Construction properties for a KMS Key Alias object.
+
+    Stability:
+        experimental
+    """
+    name: str
+    """The name of the alias.
+
+    The name must start with alias followed by a
+    forward slash, such as alias/. You can't specify aliases that begin with
+    alias/AWS. These aliases are reserved.
+
+    Stability:
+        experimental
+    """
+
+    targetKey: "IKey"
+    """The ID of the key for which you are creating the alias.
+
+    Specify the key's
+    globally unique identifier or Amazon Resource Name (ARN). You can't
+    specify another alias.
+
+    Stability:
+        experimental
+    """
+
 class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnAlias"):
     """A CloudFormation ``AWS::KMS::Alias``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html
+    Stability:
+        experimental
     cloudformationResource:
         AWS::KMS::Alias
     """
@@ -29,6 +78,9 @@ class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
             props: - resource properties.
             aliasName: ``AWS::KMS::Alias.AliasName``.
             targetKeyId: ``AWS::KMS::Alias.TargetKeyId``.
+
+        Stability:
+            experimental
         """
         props: CfnAliasProps = {"aliasName": alias_name, "targetKeyId": target_key_id}
 
@@ -39,23 +91,38 @@ class CfnAlias(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws
         """
         Arguments:
             properties: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "renderProperties", [properties])
 
     @classproperty
     @jsii.member(jsii_name="resourceTypeName")
     def RESOURCE_TYPE_NAME(cls) -> str:
-        """The CloudFormation resource type name for this resource class."""
+        """The CloudFormation resource type name for this resource class.
+
+        Stability:
+            experimental
+        """
         return jsii.sget(cls, "resourceTypeName")
 
     @property
     @jsii.member(jsii_name="aliasName")
     def alias_name(self) -> str:
+        """
+        Stability:
+            experimental
+        """
         return jsii.get(self, "aliasName")
 
     @property
     @jsii.member(jsii_name="propertyOverrides")
     def property_overrides(self) -> "CfnAliasProps":
+        """
+        Stability:
+            experimental
+        """
         return jsii.get(self, "propertyOverrides")
 
 
@@ -65,12 +132,16 @@ class CfnAliasProps(jsii.compat.TypedDict):
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html
+    Stability:
+        experimental
     """
     aliasName: str
     """``AWS::KMS::Alias.AliasName``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-aliasname
+    Stability:
+        experimental
     """
 
     targetKeyId: str
@@ -78,6 +149,8 @@ class CfnAliasProps(jsii.compat.TypedDict):
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-alias.html#cfn-kms-alias-targetkeyid
+    Stability:
+        experimental
     """
 
 class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnKey"):
@@ -85,6 +158,8 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html
+    Stability:
+        experimental
     cloudformationResource:
         AWS::KMS::Key
     """
@@ -102,6 +177,9 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
             keyUsage: ``AWS::KMS::Key.KeyUsage``.
             pendingWindowInDays: ``AWS::KMS::Key.PendingWindowInDays``.
             tags: ``AWS::KMS::Key.Tags``.
+
+        Stability:
+            experimental
         """
         props: CfnKeyProps = {"keyPolicy": key_policy}
 
@@ -130,19 +208,28 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
         """
         Arguments:
             properties: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "renderProperties", [properties])
 
     @classproperty
     @jsii.member(jsii_name="resourceTypeName")
     def RESOURCE_TYPE_NAME(cls) -> str:
-        """The CloudFormation resource type name for this resource class."""
+        """The CloudFormation resource type name for this resource class.
+
+        Stability:
+            experimental
+        """
         return jsii.sget(cls, "resourceTypeName")
 
     @property
     @jsii.member(jsii_name="keyArn")
     def key_arn(self) -> str:
         """
+        Stability:
+            experimental
         cloudformationAttribute:
             Arn
         """
@@ -151,11 +238,19 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
     @property
     @jsii.member(jsii_name="keyId")
     def key_id(self) -> str:
+        """
+        Stability:
+            experimental
+        """
         return jsii.get(self, "keyId")
 
     @property
     @jsii.member(jsii_name="propertyOverrides")
     def property_overrides(self) -> "CfnKeyProps":
+        """
+        Stability:
+            experimental
+        """
         return jsii.get(self, "propertyOverrides")
 
     @property
@@ -167,6 +262,9 @@ class CfnKey(aws_cdk.cdk.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-c
         initiation or by calling methods on this object. If both techniques are
         used only the tags from the TagManager will be used. ``Tag`` (aspect)
         will use the manager.
+
+        Stability:
+            experimental
         """
         return jsii.get(self, "tags")
 
@@ -178,36 +276,48 @@ class _CfnKeyProps(jsii.compat.TypedDict, total=False):
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-description
+    Stability:
+        experimental
     """
     enabled: typing.Union[bool, aws_cdk.cdk.Token]
     """``AWS::KMS::Key.Enabled``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enabled
+    Stability:
+        experimental
     """
     enableKeyRotation: typing.Union[bool, aws_cdk.cdk.Token]
     """``AWS::KMS::Key.EnableKeyRotation``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-enablekeyrotation
+    Stability:
+        experimental
     """
     keyUsage: str
     """``AWS::KMS::Key.KeyUsage``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keyusage
+    Stability:
+        experimental
     """
     pendingWindowInDays: typing.Union[jsii.Number, aws_cdk.cdk.Token]
     """``AWS::KMS::Key.PendingWindowInDays``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-pendingwindowindays
+    Stability:
+        experimental
     """
     tags: typing.List[aws_cdk.cdk.CfnTag]
     """``AWS::KMS::Key.Tags``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-tags
+    Stability:
+        experimental
     """
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.CfnKeyProps", jsii_struct_bases=[_CfnKeyProps])
@@ -216,15 +326,88 @@ class CfnKeyProps(_CfnKeyProps):
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html
+    Stability:
+        experimental
     """
     keyPolicy: typing.Union[typing.Mapping[typing.Any, typing.Any], aws_cdk.cdk.Token]
     """``AWS::KMS::Key.KeyPolicy``.
 
     See:
         http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html#cfn-kms-key-keypolicy
+    Stability:
+        experimental
     """
 
-class EncryptionKeyAlias(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.EncryptionKeyAlias"):
+@jsii.interface(jsii_type="@aws-cdk/aws-kms.IAlias")
+class IAlias(aws_cdk.cdk.IResource, jsii.compat.Protocol):
+    """A KMS Key alias.
+
+    Stability:
+        experimental
+    """
+    @staticmethod
+    def __jsii_proxy_class__():
+        return _IAliasProxy
+
+    @property
+    @jsii.member(jsii_name="aliasName")
+    def alias_name(self) -> str:
+        """The name of the alias.
+
+        Stability:
+            experimental
+        attribute:
+            AliasName
+        """
+        ...
+
+    @property
+    @jsii.member(jsii_name="aliasTargetKey")
+    def alias_target_key(self) -> "IKey":
+        """The Key to which the Alias refers.
+
+        Stability:
+            experimental
+        attribute:
+            TargetKeyId
+        """
+        ...
+
+
+class _IAliasProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
+    """A KMS Key alias.
+
+    Stability:
+        experimental
+    """
+    __jsii_type__ = "@aws-cdk/aws-kms.IAlias"
+    @property
+    @jsii.member(jsii_name="aliasName")
+    def alias_name(self) -> str:
+        """The name of the alias.
+
+        Stability:
+            experimental
+        attribute:
+            AliasName
+        """
+        return jsii.get(self, "aliasName")
+
+    @property
+    @jsii.member(jsii_name="aliasTargetKey")
+    def alias_target_key(self) -> "IKey":
+        """The Key to which the Alias refers.
+
+        Stability:
+            experimental
+        attribute:
+            TargetKeyId
+        """
+        return jsii.get(self, "aliasTargetKey")
+
+
+@jsii.implements(IAlias)
+class Alias(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Alias"):
     """Defines a display name for a customer master key (CMK) in AWS Key Management Service (AWS KMS).
 
     Using an alias to refer to a key can help you simplify key
@@ -233,51 +416,74 @@ class EncryptionKeyAlias(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_ty
     Working with Aliases in the AWS Key Management Service Developer Guide.
 
     You can also add an alias for a key by calling ``key.addAlias(alias)``.
+
+    Stability:
+        experimental
+    resource:
+        AWS::KMS::Alias
     """
-    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, alias: str, key: "IKey") -> None:
+    def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, name: str, target_key: "IKey") -> None:
         """
         Arguments:
             scope: -
             id: -
             props: -
-            alias: The name of the alias. The name must start with alias followed by a forward slash, such as alias/. You can't specify aliases that begin with alias/AWS. These aliases are reserved.
-            key: The ID of the key for which you are creating the alias. Specify the key's globally unique identifier or Amazon Resource Name (ARN). You can't specify another alias.
-        """
-        props: EncryptionKeyAliasProps = {"alias": alias, "key": key}
+            name: The name of the alias. The name must start with alias followed by a forward slash, such as alias/. You can't specify aliases that begin with alias/AWS. These aliases are reserved.
+            targetKey: The ID of the key for which you are creating the alias. Specify the key's globally unique identifier or Amazon Resource Name (ARN). You can't specify another alias.
 
-        jsii.create(EncryptionKeyAlias, self, [scope, id, props])
+        Stability:
+            experimental
+        """
+        props: AliasProps = {"name": name, "targetKey": target_key}
+
+        jsii.create(Alias, self, [scope, id, props])
+
+    @jsii.member(jsii_name="fromAliasAttributes")
+    @classmethod
+    def from_alias_attributes(cls, scope: aws_cdk.cdk.Construct, id: str, *, alias_name: str, alias_target_key: "IKey") -> "IAlias":
+        """
+        Arguments:
+            scope: -
+            id: -
+            attrs: -
+            aliasName: 
+            aliasTargetKey: 
+
+        Stability:
+            experimental
+        """
+        attrs: AliasAttributes = {"aliasName": alias_name, "aliasTargetKey": alias_target_key}
+
+        return jsii.sinvoke(cls, "fromAliasAttributes", [scope, id, attrs])
 
     @property
     @jsii.member(jsii_name="aliasName")
     def alias_name(self) -> str:
-        """The name of the alias."""
+        """The name of the alias.
+
+        Stability:
+            experimental
+        """
         return jsii.get(self, "aliasName")
 
-    @alias_name.setter
-    def alias_name(self, value: str):
-        return jsii.set(self, "aliasName", value)
+    @property
+    @jsii.member(jsii_name="aliasTargetKey")
+    def alias_target_key(self) -> "IKey":
+        """The Key to which the Alias refers.
 
+        Stability:
+            experimental
+        """
+        return jsii.get(self, "aliasTargetKey")
 
-@jsii.data_type(jsii_type="@aws-cdk/aws-kms.EncryptionKeyAliasProps", jsii_struct_bases=[])
-class EncryptionKeyAliasProps(jsii.compat.TypedDict):
-    alias: str
-    """The name of the alias.
-
-    The name must start with alias followed by a
-    forward slash, such as alias/. You can't specify aliases that begin with
-    alias/AWS. These aliases are reserved.
-    """
-
-    key: "IKey"
-    """The ID of the key for which you are creating the alias.
-
-    Specify the key's
-    globally unique identifier or Amazon Resource Name (ARN). You can't
-    specify another alias.
-    """
 
 @jsii.interface(jsii_type="@aws-cdk/aws-kms.IKey")
 class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
+    """A KMS Key, either managed by this CDK app, or imported.
+
+    Stability:
+        experimental
+    """
     @staticmethod
     def __jsii_proxy_class__():
         return _IKeyProxy
@@ -287,17 +493,22 @@ class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
     def key_arn(self) -> str:
         """The ARN of the key.
 
+        Stability:
+            experimental
         attribute:
             true
         """
         ...
 
     @jsii.member(jsii_name="addAlias")
-    def add_alias(self, alias: str) -> "EncryptionKeyAlias":
+    def add_alias(self, alias: str) -> "Alias":
         """Defines a new alias for the key.
 
         Arguments:
             alias: -
+
+        Stability:
+            experimental
         """
         ...
 
@@ -308,6 +519,9 @@ class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
         Arguments:
             statement: The policy statement to add.
             allowNoOp: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
+
+        Stability:
+            experimental
         """
         ...
 
@@ -318,6 +532,9 @@ class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
         Arguments:
             grantee: -
             actions: -
+
+        Stability:
+            experimental
         """
         ...
 
@@ -327,6 +544,9 @@ class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
 
         Arguments:
             grantee: -
+
+        Stability:
+            experimental
         """
         ...
 
@@ -336,6 +556,9 @@ class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
 
         Arguments:
             grantee: -
+
+        Stability:
+            experimental
         """
         ...
 
@@ -345,28 +568,41 @@ class IKey(aws_cdk.cdk.IResource, jsii.compat.Protocol):
 
         Arguments:
             grantee: -
+
+        Stability:
+            experimental
         """
         ...
 
 
 class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
+    """A KMS Key, either managed by this CDK app, or imported.
+
+    Stability:
+        experimental
+    """
     __jsii_type__ = "@aws-cdk/aws-kms.IKey"
     @property
     @jsii.member(jsii_name="keyArn")
     def key_arn(self) -> str:
         """The ARN of the key.
 
+        Stability:
+            experimental
         attribute:
             true
         """
         return jsii.get(self, "keyArn")
 
     @jsii.member(jsii_name="addAlias")
-    def add_alias(self, alias: str) -> "EncryptionKeyAlias":
+    def add_alias(self, alias: str) -> "Alias":
         """Defines a new alias for the key.
 
         Arguments:
             alias: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "addAlias", [alias])
 
@@ -377,6 +613,9 @@ class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
         Arguments:
             statement: The policy statement to add.
             allowNoOp: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "addToResourcePolicy", [statement, allow_no_op])
 
@@ -387,8 +626,11 @@ class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
         Arguments:
             grantee: -
             actions: -
+
+        Stability:
+            experimental
         """
-        return jsii.invoke(self, "grant", [grantee, actions])
+        return jsii.invoke(self, "grant", [grantee, *actions])
 
     @jsii.member(jsii_name="grantDecrypt")
     def grant_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
@@ -396,6 +638,9 @@ class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
 
         Arguments:
             grantee: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "grantDecrypt", [grantee])
 
@@ -405,6 +650,9 @@ class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
 
         Arguments:
             grantee: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "grantEncrypt", [grantee])
 
@@ -414,13 +662,22 @@ class _IKeyProxy(jsii.proxy_for(aws_cdk.cdk.IResource)):
 
         Arguments:
             grantee: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
 
 
 @jsii.implements(IKey)
-class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Key"):
-    """Defines a KMS key."""
+class Key(aws_cdk.cdk.Resource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.Key"):
+    """Defines a KMS key.
+
+    Stability:
+        experimental
+    resource:
+        AWS::KMS::Key
+    """
     def __init__(self, scope: aws_cdk.cdk.Construct, id: str, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, enable_key_rotation: typing.Optional[bool]=None, policy: typing.Optional[aws_cdk.aws_iam.PolicyDocument]=None, retain: typing.Optional[bool]=None) -> None:
         """
         Arguments:
@@ -432,6 +689,9 @@ class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
             enableKeyRotation: Indicates whether AWS KMS rotates the key. Default: false
             policy: Custom policy document to attach to the KMS key. Default: - A policy document with permissions for the account root to administer the key will be created.
             retain: Whether the encryption key should be retained when it is removed from the Stack. This is useful when one wants to retain access to data that was encrypted with a key that is being retired. Default: true
+
+        Stability:
+            experimental
         """
         props: KeyProps = {}
 
@@ -455,20 +715,27 @@ class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
     @jsii.member(jsii_name="fromKeyArn")
     @classmethod
     def from_key_arn(cls, scope: aws_cdk.cdk.Construct, id: str, key_arn: str) -> "IKey":
-        """
+        """Import an externally defined KMS Key using its ARN.
+
         Arguments:
-            scope: -
-            id: -
-            keyArn: -
+            scope: the construct that will "own" the imported key.
+            id: the id of the imported key in the construct tree.
+            keyArn: the ARN of an existing KMS key.
+
+        Stability:
+            experimental
         """
         return jsii.sinvoke(cls, "fromKeyArn", [scope, id, key_arn])
 
     @jsii.member(jsii_name="addAlias")
-    def add_alias(self, alias: str) -> "EncryptionKeyAlias":
+    def add_alias(self, alias: str) -> "Alias":
         """Defines a new alias for the key.
 
         Arguments:
             alias: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "addAlias", [alias])
 
@@ -479,6 +746,9 @@ class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
         Arguments:
             statement: The policy statement to add.
             allowNoOp: If this is set to ``false`` and there is no policy defined (i.e. external key), the operation will fail. Otherwise, it will no-op.
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "addToResourcePolicy", [statement, allow_no_op])
 
@@ -493,8 +763,11 @@ class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
         Arguments:
             grantee: -
             actions: -
+
+        Stability:
+            experimental
         """
-        return jsii.invoke(self, "grant", [grantee, actions])
+        return jsii.invoke(self, "grant", [grantee, *actions])
 
     @jsii.member(jsii_name="grantDecrypt")
     def grant_decrypt(self, grantee: aws_cdk.aws_iam.IGrantable) -> aws_cdk.aws_iam.Grant:
@@ -502,6 +775,9 @@ class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
 
         Arguments:
             grantee: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "grantDecrypt", [grantee])
 
@@ -511,6 +787,9 @@ class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
 
         Arguments:
             grantee: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "grantEncrypt", [grantee])
 
@@ -520,13 +799,20 @@ class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
 
         Arguments:
             grantee: -
+
+        Stability:
+            experimental
         """
         return jsii.invoke(self, "grantEncryptDecrypt", [grantee])
 
     @property
     @jsii.member(jsii_name="keyArn")
     def key_arn(self) -> str:
-        """The ARN of the key."""
+        """The ARN of the key.
+
+        Stability:
+            experimental
+        """
         return jsii.get(self, "keyArn")
 
     @property
@@ -536,13 +822,20 @@ class Key(aws_cdk.cdk.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aw
 
         If specified, addToResourcePolicy can be used to edit this policy.
         Otherwise this method will no-op.
+
+        Stability:
+            experimental
         """
         return jsii.get(self, "policy")
 
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.KeyProps", jsii_struct_bases=[])
 class KeyProps(jsii.compat.TypedDict, total=False):
-    """Construction properties for a KMS Key object."""
+    """Construction properties for a KMS Key object.
+
+    Stability:
+        experimental
+    """
     description: str
     """A description of the key.
 
@@ -551,6 +844,9 @@ class KeyProps(jsii.compat.TypedDict, total=False):
 
     Default:
         - No description.
+
+    Stability:
+        experimental
     """
 
     enabled: bool
@@ -558,6 +854,9 @@ class KeyProps(jsii.compat.TypedDict, total=False):
 
     Default:
         - Key is enabled.
+
+    Stability:
+        experimental
     """
 
     enableKeyRotation: bool
@@ -565,6 +864,9 @@ class KeyProps(jsii.compat.TypedDict, total=False):
 
     Default:
         false
+
+    Stability:
+        experimental
     """
 
     policy: aws_cdk.aws_iam.PolicyDocument
@@ -573,6 +875,9 @@ class KeyProps(jsii.compat.TypedDict, total=False):
     Default:
         - A policy document with permissions for the account root to
           administer the key will be created.
+
+    Stability:
+        experimental
     """
 
     retain: bool
@@ -583,30 +888,48 @@ class KeyProps(jsii.compat.TypedDict, total=False):
 
     Default:
         true
+
+    Stability:
+        experimental
     """
 
 class ViaServicePrincipal(aws_cdk.aws_iam.PrincipalBase, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.ViaServicePrincipal"):
-    """A principal to allow access to a key if it's being used through another AWS service."""
+    """A principal to allow access to a key if it's being used through another AWS service.
+
+    Stability:
+        experimental
+    """
     def __init__(self, service_name: str, base_principal: typing.Optional[aws_cdk.aws_iam.IPrincipal]=None) -> None:
         """
         Arguments:
             serviceName: -
             basePrincipal: -
+
+        Stability:
+            experimental
         """
         jsii.create(ViaServicePrincipal, self, [service_name, base_principal])
 
     @property
     @jsii.member(jsii_name="policyFragment")
     def policy_fragment(self) -> aws_cdk.aws_iam.PrincipalPolicyFragment:
-        """Return the policy fragment that identifies this principal in a Policy."""
+        """Return the policy fragment that identifies this principal in a Policy.
+
+        Stability:
+            experimental
+        """
         return jsii.get(self, "policyFragment")
 
     @property
     @jsii.member(jsii_name="serviceName")
     def service_name(self) -> str:
+        """
+        Stability:
+            experimental
+        """
         return jsii.get(self, "serviceName")
 
 
-__all__ = ["CfnAlias", "CfnAliasProps", "CfnKey", "CfnKeyProps", "EncryptionKeyAlias", "EncryptionKeyAliasProps", "IKey", "Key", "KeyProps", "ViaServicePrincipal", "__jsii_assembly__"]
+__all__ = ["Alias", "AliasAttributes", "AliasProps", "CfnAlias", "CfnAliasProps", "CfnKey", "CfnKeyProps", "IAlias", "IKey", "Key", "KeyProps", "ViaServicePrincipal", "__jsii_assembly__"]
 
 publication.publish()
